--[[
Author: Starinnia
CPR is a combo points display addon based on Funkydude's BasicComboPoints
Embers.lua - A module for tracking Burning Embers
$Date: 2012-08-30 16:21:36 +0000 (Thu, 30 Aug 2012) $
$Revision: 264 $
Project Version: r264
contact: codemaster2010 AT gmail DOT com

Copyright (c) 2007-2012 Michael J. Murray aka Lyte of Lothar(US)
All rights reserved unless otherwise explicitly stated.
]]

if select(2, UnitClass("player")) ~= "WARLOCK" then return end

local cpr = LibStub("AceAddon-3.0"):GetAddon("ComboPointsRedux")
local modName = "Burning Embers"
local mod = cpr:NewModule(modName)
local FILE_HEIGHT = 32 --all icon files are 32 tall

function mod:OnInitialize()
	self.MAX_POINTS = 3
	self.displayName = GetSpellInfo(116854)
	self.abbrev = "BE"
	self.events = { ["UNIT_POWER"] = "Update", ["UNIT_DISPLAYPOWER"] = "Update" }
end

--determines the textCoords to show a fractional power value
--and handles showing and hiding the icon
local function fractionalFill(point, power, maxPer)
	local db = cpr.db.profile.modules[modName]
	local icon = point.icon
	
	if power <= 0 then
		point:Hide()
	elseif power >= maxPer then
		icon:SetTexCoord(0, 1, 0, 1) --show the uncut image
		icon:SetHeight(25*db.scale)
		point:Show()
	else
		--set fractional texture coords
		local texHeight = (value / maxValue) * (25*db.scale)
		local top = 1 - texHeight / FILE_HEIGHT
		icon:SetTexCoord(0, 1, top, 1)
		icon:SetHeight(texHeight)
		point:Show()
	end
end

local oldCount = 0
function mod:Update()
	--third param for fractional values
	--this will return values from 0 to 30 (10 power per ember)
	local power = UnitPower("player", SPELL_POWER_BURNING_EMBERS, true)
	
	if power > 0 then
		if self.graphics then
			for i = 1, self.MAX_POINTS do
				fractionalFill(self.graphics.points[i], power, MAX_POWER_PER_EMBER)
				--left over for the next point
				power = power - MAX_POWER_PER_EMBER
			end
		end
		if self.text then self.text:SetNumPoints(format('%.1f', power / MAX_POWER_PER_EMBER)) end
		
		--should prevent spamming issues when UNIT_AURA fires and
		--the aura we care about hasn't changed
		if oldCount ~= count then
			oldCount = count
			cpr:DoFlash(modName, count)
		end
	else
		if self.graphics then
			for i = 1, self.MAX_POINTS do
				self.graphics.points[i]:Hide()
			end
		end
		if self.text then self.text:SetNumPoints("") end
		
		oldCount = 0
	end
end
